plugin top-level property

Plugin plugin
final

The plugin instance that the Dart Analysis Server loads.

This top-level variable must be present for the analyzer to detect and load the plugin.

Implementation

final Plugin plugin = DebangLintPlugin();