main library
Analyzer plugin for the debang package.
Enforces minimum message length for debang() or Debang() calls to ensure
descriptive debug messages.
Enable in a project
Add to analysis_options.yaml:
plugins:
debang_lints: ^1.1.0
Then restart Analysis Server in your IDE.
value.debang("Won't be null"); // ❌ Too short
value.debang("Value won't be null because it's initialized after authorization."); // ✅ OK
Classes
- DebangAssertionTooShortRule
- Analysis rule that checks minimum message length for debang assertions.
- DebangLintPlugin
- Main plugin class that registers custom analysis rules.
- DebangMissingAuthorRule
-
Analysis rule that checks debang assertions have an author name,
similar to the
TODO(username)convention.
Properties
- plugin → Plugin
-
The plugin instance that the Dart Analysis Server loads.
final